RTD Dropdown for MkDocs
=======================
[![Pypi Version][pypi-image]][pypi-link]

  [pypi-image]: http://img.shields.io/pypi/v/mkdocs-rtd-dropdown.svg
  [pypi-link]: https://pypi.python.org/pypi/mkdocs-rtd-dropdown

A ReadTheDocs theme for [MkDocs](http://www.mkdocs.org/)

![Dropdown Demo](docs/img/example.png)



Features
--------

* Based on the [MkDocs ReadTheDocs](https://github.com/mkdocs/mkdocs/tree/master/mkdocs/themes) theme
* Adds dropdown functionality to mimic ReadTheDocs

For further discussion, see [this issue](https://github.com/mkdocs/mkdocs/issues/588).


How to use
----------

Install ReadTheDocs Dropdown with pip:

```
pip install mkdocs-rtd-dropdown
```

Set theme to rtd-dropdown in your projects `mkdocs.yml`:

```
theme:
  name: 'rtd-dropdown'
```
